.. _spider_tvthek.orf.at:

tvthek.orf.at
-------------
Newest episodes of TV shows from `ORF TVthek <https://tvthek.orf.at>`_.

Configuration
~~~~~~~~~~~~~
Add ``tvthek.orf.at`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     tvthek.orf.at

